@@ -10,13 +10,13 @@
 #
 # $Project: /Convert-Binary-C $
 # $Author: mhx $
-# $Date: 2007/06/11 20:59:37 +0200 $
-# $Revision: 24 $
+# $Date: 2008/04/15 15:37:41 +0200 $
+# $Revision: 27 $
 # $Source: /token/config.pl $
 #
 ################################################################################
 #
-# Copyright (c) 2002-2007 Marcus Holland-Moritz. All rights reserved.
+# Copyright (c) 2002-2008 Marcus Holland-Moritz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 #
@@ -51,6 +51,8 @@ use Devel::Tokenizer::C;
   HasMacroVAARGS
   OrderMembers
   Bitfields
+  StdCVersion
+  HostedC
 );
 
 @sourcify = qw(
